#
# spec file for package cgal
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2014 Ioda-Net Sàrl, Charmoille, Switzerland.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#@TODO : clarify and split licence correctly, GPL & LGPL 3+ version
#@TODO : split package in coherent parts
#@TODO : rename parts (inspirated by sfcgal packaging)
#@TODO : ask for rename and take into account the obsolete existant thing. like libcgal deps
%define _sourcename CGAL
Name:           cgal
Version:        5.6.2
Release:        1.1
Summary:        Computational Geometry Algorithms Library
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Productivity/Graphics/CAD
URL:            https://www.cgal.org/
Source0:        https://github.com/CGAL/cgal/releases/download/v%{version}/CGAL-%{version}.tar.xz
Source1:        https://github.com/CGAL/cgal/releases/download/v%{version}/CGAL-%{version}-doc_html.tar.xz
Source2:        cgal-rpmlintrc
BuildRequires:  blas-devel
BuildRequires:  cmake >= 3.14
BuildRequires:  fdupes
BuildRequires:  glu-devel
BuildRequires:  gmp-devel
BuildRequires:  lapack-devel
BuildRequires:  libboost_atomic-devel >= 1.66
BuildRequires:  libboost_system-devel >= 1.66
BuildRequires:  libboost_thread-devel >= 1.66
BuildRequires:  mpfr-devel
BuildRequires:  xz
BuildRequires:  zlib-devel
Requires:       libcgal-devel = %{version}
%if 0%{?sle_version} >= 150400 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++
%endif

%description
CGAL provides geometric algorithms in a C++ library.

The library offers data structures and algorithms like
triangulations, Voronoi diagrams, Boolean operations on polygons and
polyhedra, point set processing, arrangements of curves, surface and
volume mesh generation, geometry processing, alpha shapes, convex
hull algorithms, shape analysis, AABB and KD trees.

%package devel
Summary:        Development files and tools for CGAL applications
License:        BSL-1.0 AND GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       blas
Requires:       cmake
Requires:       gmp-devel
Requires:       lapack
Requires:       libboost_atomic-devel
Requires:       libboost_system-devel
Requires:       libboost_thread-devel
Requires:       mpfr-devel
Requires:       zlib-devel
#For compatibility with package looking for our old name
Provides:       libcgal-devel = %{version}

%description devel
This package provides the headers files and tools you may need to
develop applications using CGAL.

%package demo-examples-devel
Summary:        Example & demo files for CGAL library usage
License:        BSL-1.0 AND GPL-3.0-or-later AND LGPL-3.0-or-later AND MIT
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
BuildArch:      noarch

%description demo-examples-devel
This package provides the sources of examples and demos of
CGAL algorithms. You can study them, compile and test CGAL
library.

%package doc
Summary:        Documentation CGAL algorithms
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package provides the documentation for CGAL algorithms.

%prep
%setup -q -n CGAL-%{version} -a1

%build
%if 0%{?sle_version} >= 150400 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
export CXX="g++-11"
%endif

%cmake -DCGAL_INSTALL_LIB_DIR=%{_lib} \
       -DCGAL_INSTALL_DOC_DIR=%{_docdir}/%{name}-doc

%make_build

# Unfortunately take +6600sec locally.
# So we just deliver the source code in cgal package.
#  -DWITH_examples=true \
#  -DWITH_demos=true \

%install
%cmake_install

install -d %{buildroot}/%{_datadir}/CGAL/examples
install -d %{buildroot}/%{_datadir}/CGAL/demo
cp -a examples/* %{buildroot}/%{_datadir}/CGAL/examples
cp -a demo/* %{buildroot}/%{_datadir}/CGAL/demo

# no macos here.
rm %{buildroot}/%{_bindir}/cgal_make_macosx_app

# installed as docs, but licenses are under %%{_datadir}/licenses/, remove duplicate
rm %{buildroot}%{_docdir}/%{name}-doc/LICENSE*

cp -a doc_html %{buildroot}/%{_docdir}/%{name}-doc/
%fdupes %{buildroot}%{_docdir}/%{name}-doc/

%fdupes %{buildroot}/%{_datadir}

%files devel
%license LICENSE*
%doc AUTHORS CHANGES.md
%{_includedir}/CGAL
%{_libdir}/cmake/CGAL
%{_bindir}/cgal_create_CMakeLists
%{_bindir}/cgal_create_cmake_script
%{_mandir}/man1/cgal_create_cmake_script.1%{?ext_man}

%files demo-examples-devel
%license LICENSE*
%{_datadir}/CGAL

%files doc
%license LICENSE*
%doc %dir %{_docdir}/%{name}-doc
%doc %{_docdir}/%{name}-doc/doc_html
%doc %{_docdir}/%{name}-doc/AUTHORS
%doc %{_docdir}/%{name}-doc/CHANGES.md

%changelog
* Wed Oct 23 2024 Michael Vetter <mvetter@suse.com>
- Update to 5.6.2:
  * https://github.com/CGAL/cgal/issues?q=sort%%3Aupdated-desc+label%%3AMerged_in_5.6.2+-label%%3AMerged_in_5.6.1
* Wed Feb 28 2024 Ben Greiner <code@bnavigator.de>
- Update to 5.6.1
  * CGAL-5.6.1 is a bug-fix release.
    See on Github the list of bugs that were solved since CGAL-5.6.
    https://github.com/CGAL/cgal/releases/tag/v5.6.1
- Fix documentation packaging: Tumbleweed uses a different default
  destination than older distributions now. Force doc subdir.
* Mon Jul 31 2023 Michael Vetter <mvetter@suse.com>
- Update to 5.6:
  * See https://github.com/CGAL/cgal/releases/tag/v5.6
* Mon Jul 31 2023 Michael Vetter <mvetter@suse.com>
- Update to 5.5.3:
  * https://github.com/CGAL/cgal/issues?q=sort%%3Aupdated-desc+label%%3AMerged_in_5.5.2+-label%%3AMerged_in_5.5.1
* Sun Apr  2 2023 Carsten Ziepke <kieltux@gmail.com>
- Use gcc11-c++ for openSUSE Leap, enables building
* Wed Mar  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 5.5.2:
  * https://github.com/CGAL/cgal/issues?q=sort%%3Aupdated-desc+label%%3AMerged_in_5.5.2+-label%%3AMerged_in_5.5.1
* Thu Nov 24 2022 Ben Greiner <code@bnavigator.de>
- Update to 5.5.1
  * bug fix release compared to 5.5.0
  * https://github.com/CGAL/cgal/pulls?q=label%%3AMerged_in_5.4.3+-label%%3AMerged_in_5.4.2
- Release 5.5.0
  * The CGAL Open Source Project is pleased to announce the release
    5.5 of CGAL, the Computational Geometry Algorithms Library.
  [#]# 3D Alpha Wrapping (new package)
  * This component takes a 3D triangle mesh, soup, or point set as
    input, and generates a valid (watertight, intersection-free,
    and combinatorially 2-manifold) surface triangle mesh that
    contains the input. The algorithm proceeds by shrink-wrapping
    and refining a 3D Delaunay triangulation, starting from a loose
    bounding box of the input. Two user-defined parameters, alpha
    and offset, offer control over the maximum size of cavities
    where the shrink-wrapping process can enter, and the tightness
    of the final surface mesh to the input, respectively. Once
    combined, these parameters provide a means to trade fidelity to
    the input for complexity of the output.
  * See also the announcement page.
    https://www.cgal.org/2022/05/18/alpha_wrap/
  [#]# 2D Straight Skeleton and Polygon Offsetting (breaking change)
  * Fix the output of the function
    CGAL::create_exterior_skeleton_and_offset_polygons_with_holes_2()
    to not take into account the offset of the outer frame.
  * Fix the computation of the exterior offset of a polygon with
    holes that was not computing the offset of the holes
  [#]# 3D Convex Hulls
  * Added an overload of the function CGAL::convex_hull_3(), which
    writes the result in an indexed triangle set.
  [#]# 2D Polygons
  * Add vertex, edge, and hole ranges.
  * The concept GeneralPolygonWithHoles_2 now requires the nested
    type Polygon_2 instead of General_polygon_2.
  [#]# 2D Regularized Boolean Set-Operations
  * The concept GeneralPolygonSetTraits_2 now requires the nested
    type Construct_polygon_with_holes_2 instead of
    Construct_general_polygon_with_holes_2.
  [#]# Combinatorial Maps
  * Removed old code deprecated in CGAL 4.9 and 4.10 (global
    functions, and information associated with darts).
  [#]# 2D Arrangements
  * Fixed the intersect_2, compare_y_at_x_right, and
    compare_y_at_x_left function objects of the traits class
    template Arr_geodesic_arc_on_sphere_traits_2 that handles
    geodesic arcs on sphere and applied a small syntactical fix to
    the tracing traits.
  [#]# Tetrahedral Mesh Generation
  * Added the function remove_isolated_vertices() as a
    post-processing step for the tetrahedral mesh generation.
  [#]# Polygon Mesh Processing
  * Added the function
    CGAL::Polygon_mesh_processing::orient_triangle_soup_with_reference_triangle_soup(),
    which enables re-orienting the faces of a triangle soup based
    on the orientation of the nearest face in a   reference
    triangle soup.
  * Added the function
    CGAL::Polygon_mesh_processing::compatible_orientations(), which
    enables to retrieve the (in)compatibility of orientations of
    faces from different connected components.
  * Added the function
    CGAL::Polygon_mesh_processing::tangential_relaxation(), which
    applies an area-based tangential mesh smoothing to the vertices
    of a surface triangle mesh.
  * Added the named parameter visitor to the function
    triangulate_hole(), which enables to track progress with
    callbacks.
  * Added more functions in the visitor of the corefinement based
    methods to track progress.
  [#]# Surface Mesh Simplification
  * Introduced four variations of the Garland-Heckbert
    simplification algorithm based on the probabilistic approach of
    Trettner and Kobbelt (Fast and Robust QEF Minimization using
    Probabilistic Quadrics):   GarlandHeckbert_plane_policies,
    GarlandHeckbert_probabilistic_plane_policies,
    GarlandHeckbert_triangle_policies, and
    GarlandHeckbert_probabilistic_triangle_policies.
  * The class GarlandHeckbert_policies has been deprecated,
    GarlandHeckbert_plane_policies replaces it.
  [#]# Point Set Processing
  * A new optional named parameter, min_points_per_cell has been
    added to grid_simplify_point_set(). By adding a minimal number
    of points in a cell such that a point is retained, one can also
    filter out low   density areas and outliers: in the case of
    densely sampled point clouds, this yields better results than
    using grid simplification and then outlier removal, while being
    very vast. The default value is 1 to   keep the previous
    behavior as default.
  [#]# dD Spatial Searching
  * Added the member function write_graphviz() to the class Kd_tree
    that writes the tree in a stream in the Graphviz format.
  [#]# CGAL and the Boost Graph Library (BGL)
  * Added the function invert_selection() in the class
    Face_filtered_graph, which toggles the selected status of a
    graph: selected faces are deselected, and unselected faces are
    selected.
* Tue Jun  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 5.4.1:
  See https://github.com/CGAL/cgal/pulls?utf8=%%E2%%9C%%93&q=label%%3AMerged_in_5.4.1
* Mon Feb 28 2022 Michael Vetter <mvetter@suse.com>
- Update to 5.4:
  See https://github.com/CGAL/cgal/releases/tag/v5.4
* Wed Aug 18 2021 Michael Vetter <mvetter@suse.com>
- Update to 5.3:
  General changes:
  * The support for the compiled version of CGAL is dropped.
    Only the header-only version is supported.
  Quadtrees, Octrees, and Orthtrees (new package):
  * This package implements a tree data structure in which each
    node encloses a hypercubic section of space and each non-leave
    node has hypercubic children whose edge lengths are half its
    edge length.  Such a data structure is known as a quadtree in 2D,
    an octree in 3D, and is generalized as an "orthtree" in higher dimensions.
  Triangulations on the Sphere (new package):
  * This package enables the construction and manipulation of Delaunay
    triangulations on the 2-sphere.  Triangulations are built incrementally
    and can be modified by insertion or removal of vertices.  Point location
    querying and primitives to build the dual Voronoi diagram are provided.
  File Input / Output:
  * Point set, polygon soup, and polygon mesh file I/O functions have been
    harmonized and documented:
  * Point set I/O functions can be found in the packages Point_set_processing_3,
    and Point_set_3.
  * Polygon mesh I/O functions can be found in the package BGL.
  * Polygon soup I/O can be found in the package Stream_support.
  * A comprehensive list of the supported file formats is available in the
    Stream_support package here; inversely, the following page can be used to
    find out which CGAL data structures can be used given a specific file format.
  2D and 3D Linear Geometry Kernel:
  * Added is_translation(), is_scaling(), is_reflection(), and is_rotation()
    to the classes Aff_transformation_2 and Aff_transformation_3, which enable
    determining if the transformations use a specialized representation internally.
  2D Regularized Boolean Set-Operations:
  * Added documentation for the free functions oriented_side(const Point_2& p, ....)
    that accept a point and a polygon.
  * Documentation has been improved across the whole package.
  Polygon Mesh Processing:
  * Added the class CGAL::Polyhedral_envelope,
    providing a way to quickly check if a primitive (point, segment, or triangle)
    is within a polyhedral envelope around a set of triangles. It is based on the work of
    Bolun Wang, Teseo Schneider, Yixin Hu, Marco Attene, and Daniele Panozzo.
    "Exact and efficient polyhedral envelope containment check." (ACM Trans. Graph., 39-4, July 2020).
  * Added more functions in the visitor of the corefinement based methods
    to track all edge creations.
  Surface Mesh Topology:
  * Added the function CGAL::Surface_mesh_topology::Curves_on_surface_topology::
    is_homotopic_to_simple_cycle(), which can be used to determine whehter
    a closed path on a surface mesh can be continously
    transformed to a cycle without self intersection.
  Surface Mesh Simplification:
  * Added a filtering mechanism so that costly tests get only applied to the
    next candidate for the edge collapse.
  * Added the class Polyhedral_envelope_filter, which enables to perform
    mesh simplification inside a polyhedral envelope of the input mesh.
  2D Polyline Simplification:
  * When polylines have common subsequences of vertices, these subsequences
    may now be simplifified simultaneously.
  dD Triangulations:
  * Added the function insert_if_in_star() to the class
    CGAL::Regular_triangulation, which enables users to insert a point p
    in a regular triangulation on the condition that p appears post-insertion
    in the star of a user-specified, existing vertex.
  2D and 3D Alpha Shapes:
  * Breaking change: The following deprecated classes have been removed:
    Alpha_shape_euclidean_traits_2, Weighted_alpha_shape_euclidean_traits_2,
    Alpha_shape_euclidean_traits_3, and Weighted_alpha_shape_euclidean_traits_3.
    All CGAL kernel can be used directly as models of the concepts of the
    2D and 3D Alpha Shape packages.
  Classification:
  * Breaking change: the support for TensorFlow has been dropped; the
    classifier CGAL::TensorFlow::Neural_network_classifier has been removed.
* Wed Aug 18 2021 Michael Vetter <mvetter@suse.com>
- Update to 5.2.3:
  See https://github.com/CGAL/cgal/issues?q=label%%3AMerged_in_5.2.3+-label%%3AMerged_in_5.2.2
* Wed Jun 30 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 5.2.2
  * See https://github.com/CGAL/cgal/issues?q=label%%3AMerged_in_5.2.2+-label%%3AMerged_in_5.2.1
* Tue Apr 13 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 5.2.1
  * See https://github.com/CGAL/cgal/pulls?utf8=%%E2%%9C%%93&q=label%%3AMerged_in_5.2.1
- Update to 5.2.0
  * Fixed multiple code execution vulnerabilities:
    boo#1184975 ( CVE-2020-35636 ), boo#1184977 ( CVE-2020-28636 ),
    boo#1184973 ( CVE-2020-28601 ) and boo#1184978 ( CVE-2020-35628 )
  * For full list of other changes, see:
    https://www.cgal.org/2020/12/22/cgal52/
* Wed Nov 18 2020 Michael Vetter <mvetter@suse.com>
- Update to 5.1.1:
  See https://github.com/CGAL/cgal/pulls?utf8=%%E2%%9C%%93&q=label%%3AMerged_in_5.1.1
* Fri Oct  2 2020 Dirk Stoecker <opensuse@dstoecker.de> 5.1
- update to version 5.1
  Many news, see https://github.com/CGAL/cgal/releases/tag/v5.1
* Sun Mar 29 2020 Simon Puchert <simonpuchert@alice.de> 5.0.2
- Update to version 5.0.2
  * various small bugfixes
- Update to version 5.0.1
  * fixes a performance regression in 3D Triangulations, when using
    the Parallel_tag
- Update to version 5.0.0
  * requires g++ 6.3 or later
  * requires boost 1.57.0 or later
  * new Polygonal Surface Reconstruction
  * See https://www.cgal.org/2019/11/08/cgal50/ for details
- manually disable header-only build
* Tue Jul 30 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build on x86_64 and some other, do not force -fPIE, -fPIC would be
  needed but is the default already.
* Fri Apr  5 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add Conflicts between libCGAL_core and old unsplit package, both
  provide the same library file.
* Thu Apr  4 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Split library package into 4 subpackages, libCGAL, libCGAL_Core
  libCGAL_ImageIO and libCGAL_Qt5, to properly adhere to the
  Shared Libraray Packaging policy, versions are no longer in sync.
- Add bcond for Qt5 component. It requires Qt5 built with Desktop
  OpenGL support, which is not available on ARM and Aarch64.
- Remove fdupes filter from rpmlintrc, not required any more.
* Mon Apr  1 2019 mvetter@suse.com
- Update to 4.14:
  * new 2D Periodic Hyperbolic Triangulations
  * new 2D Hyperbolic Triangulations
  * new The Heat Method
  * new Triangulated Surface Mesh Approximation
  * For bugfixes and details see:
    https://www.cgal.org/2019/03/29/cgal414/
* Tue Oct  2 2018 mvetter@suse.com
- Update to 4.13:
  * Added: 3D Periodic Mesh Generation
  * Classification package can now handle classification of surface
  meshes and clusters, and can compute features in parallel.
  * For list of more changes and bugfixes see:
    https://www.cgal.org/2018/10/01/cgal413/
* Wed Sep  5 2018 mvetter@suse.com
- Update to 4.12.1:
  Please see https://github.com/CGAL/cgal/milestone/33?closed=1
  for the full list of fixed bugs
* Mon Jun 18 2018 stefan.bruens@rwth-aachen.de
- Use correct BuildRequires for libboost_atomic-devel
- Manually install documentation, %%doc does not preserve symlinks
- Cleanup
* Mon Apr 30 2018 jengelh@inai.de
- Use %%setup logic to extract supplementary source archives.
* Thu Apr 26 2018 mvetter@suse.com
- Remove cgal-4.11-opengl-es-arm.patch: upstreamed
- Update to 4.12:
  * New 2D Movable Separability of Sets
  * Classification: algorithm that classifies a data set into a
    user-defined set of labels
  * Removed Kinetic Data Structures
  * See https://www.cgal.org/2018/04/25/cgal412/ for a complete
    list of changes
* Tue Feb 27 2018 mvetter@suse.com
- Update to 4.11.1:
  * Bug fix release
    Please see https://github.com/CGAL/cgal/milestone/28?closed=1
  for the full list of fixed bugs
* Thu Dec  7 2017 normand@linux.vnet.ibm.com
- remove in spec the Requires: qt-devel that is Qt4 related
* Wed Sep 27 2017 mvetter@suse.com
- Always use Qt5
* Wed Sep 27 2017 mvetter@suse.com
- boo#1060631: Add cgal-4.11-opengl-es-arm.patch
  On armv7 Qt uses OpenGL ES headers.
  cgal included GL/gl.h desktop header, but they cannot be mixed.
* Wed Sep 27 2017 mvetter@suse.com
- Remove boost conditionals. They are handled in prj conf.
* Tue Sep 26 2017 mvetter@suse.com
- Update to 4.11
  * details can be found in CHANGES file
* Tue Feb  7 2017 jengelh@inai.de
- Redo description and RPM groups
- Rename %%_soname to %%_sover to better reflect its use
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sun Nov 22 2015 wk@ire.pw.edu.pl
- fixed build for SLE-12 and some earlier releases
* Tue Nov 17 2015 mpluskal@suse.com
- Update to 4.7
  * switch to qt5
  * details can be found in CHANGES file
- Use github for download urls
* Mon Sep 28 2015 mpluskal@suse.com
- Update to 4.6.3
  * details can be found in CHANGES file
* Tue Sep  1 2015 dimstar@opensuse.org
- Fix Source URLs.
* Wed Aug 19 2015 adrian@suse.de
- Update to 4.6.1
  * details can be found in CHANGES file
* Sat Feb 28 2015 mpluskal@suse.com
- Remove conditionals and use only cmake macros for building
* Sat Feb 28 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Remove sha256sum.txt
- Update to 4.5.2
  * Fix a bug that prevented the compilation with recent versions
    of Boost (>=1.56) when explicit conversions operators
    (from C++11) are supported. That prevented the compilation with
    Microsoft Visual Studio 2013.
  * 3D Convex Hulls: Fix a non-robust predicate bug that was
    showing up when input points where lexicographically sorted.
  * 3D Mesh Generation: Fix a bug in the sliver perturbation
    optimization method. It could create some holes on the
    surface of the mesh.
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 4.5.1,http://www.cgal.org/releases.html#release4.5.1
- Bump sover to 10.0.4
* Tue Jun  3 2014 bruno@ioda-net.ch
- update to 4.4, see http://www.cgal.org/releases.html#release4.4
- packaging : remove libcgal%%soname as main package
- cgal is dumb empty package
- libcgalsoname contain only library
- cgal-demo-examples-devel contain all demo and example
- cgal-doc contain the whole documentation
- Fix & cleanup Licence as specified in sources
- Make it build for SLE with exception for noarch.
* Tue Dec 17 2013 coolo@suse.com
- update to 4.3, see http://www.cgal.org/releases.html#release4.3
* Sat Jan 19 2013 prusnak@opensuse.org
- updated to 4.1
* Fri Aug  3 2012 jw@suse.com
- added happy_gcc.patch
  fixed c++ syntax for a more strict gcc
* Fri Aug  3 2012 jw@suse.com
- fixed Group and License
* Fri Aug  3 2012 jw@suse.com
- added boost149workaround.patch
* Sun Jan  8 2012 prusnak@opensuse.org
- updated to 3.9
* Sat May 14 2011 prusnak@opensuse.org
- don't build Qt3 library anymore
- use fdupes
* Fri May 13 2011 prusnak@opensuse.org
- based on a Fedora package by Laurent Rineau (version 3.8)
